#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import sys

def generate_instance(num_rooms):
    problemfile = "prob%02d.pddl" % num_rooms
    pf = open(problemfile, "w")

    lines = []
    problem_name = "chainOfRooms%02d" % num_rooms
    room_list = ["r%d" % r for r in range(1,num_rooms+1)]

    lines.append("(define (problem %s)" % problem_name)
    lines.append("  (:domain chainOfRooms)")
    lines.append("  (:objects %s - room)" % (" ".join(room_list),))
    lines.append("  (:init (agent_position r1)")
    lines.append("         (visited r1)")
    for r in room_list:
        lines.append("         (light_off %s)" % r)
    for rl, rr in zip(room_list,room_list[1:]):
        lines.append("         (adjacent %s %s)" % (rl, rr))
    lines.append("   )")
    lines.append("  (:goal (and (visited r1)")
    for r in room_list[1:]:
        lines.append("         (visited %s)" % r)
    lines.append("         )")
    lines.append("  )")
    lines.append(")")

    for line in lines:
        print(line, file=pf)
    pf.flush()
    pf.close()

if __name__ == '__main__':
    try:
        num_rooms = int(sys.argv[1])
        assert num_rooms >= 1
    except (IndexError, AssertionError):
        print("ERROR: %s expects the number of rooms (a positive integer) as the first argument." % sys.argv[0])
        print("       Setting number of rooms to 1.")
        num_rooms = 1
        
    generate_instance(num_rooms)
